ConnectableStreamSubscription<T> class

A special StreamSubscription that not only cancels the connection to the source Stream, but also closes down a subject that drives the Stream.

Inheritance
Available extensions

Constructors

ConnectableStreamSubscription(StreamSubscription<T> _source, Subject<T> _subject)
Constructs a special StreamSubscription, which will close the provided subject when cancel is called.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
Whether the StreamSubscription is currently paused.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTo(CompositeSubscription compositeSubscription) → void

Available on StreamSubscription<T>, provided by the AddToCompositeSubscriptionExtension extension

Adds this subscription to composite container for subscriptions.
asFuture<E>([E? futureValue]) → Never
Returns a future that handles the onDone and onError callbacks.
override
cancel() → Future
Cancels this subscription.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onData(void handleData(T data)?) → Never
Replaces the data event handler of this subscription.
override
onDone(void handleDone()?) → Never
Replaces the done event handler of this subscription.
override
onError(Function? handleError) → Never
Replaces the error event handler of this subscription.
override
pause([Future<void>? resumeSignal]) → void
Requests that the stream pauses events until further notice.
override
resume() → void
Resumes after a pause.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited