ErrorNotification class

A notification representing an error event from a Stream.

Inheritance

Constructors

ErrorNotification(ErrorAndStackTrace errorAndStackTrace)
Constructs an ErrorNotification with the provided errorAndStackTrace.
const

Properties

error → Object
The error of the error event.
no setter
errorAndStackTrace → ErrorAndStackTrace
The wrapped error and stack trace, if applicable
final
hashCode → int
The hash code for this object.
no setteroverride
kind → NotificationKind
References the NotificationKind of this StreamNotification event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace of the error event, if available.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override