SkipLastStreamTransformer<T> class

Skip the last count items emitted by the source Stream

Example

Stream.fromIterable([1, 2, 3, 4, 5])
  .transform(SkipLastStreamTransformer(3))
  .listen(print); // prints 1, 2
Inheritance

Constructors

SkipLastStreamTransformer(int count)
Constructs a StreamTransformer which skip the last count items emitted by the source Stream

Properties

count → int
The count of final items to skip.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<T> stream) → Stream<T>
Transforms the provided stream.
override
cast<RS, RT>() → StreamTransformer<RS, RT>
Provides a StreamTransformer<RS, RT> view of this stream transformer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited